@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import http.client as http
+
 from oslo_serialization import jsonutils
 import requests
-from six.moves import http_client as http
 
 from glance.tests.functional.v2 import metadef_base
 
